# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class TokenTimestamp(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "block_timestamp",
            "block_number",
            "transaction_hash",
            "direction",
        }
        
        class properties:
            block_number = schemas.StrSchema
            block_timestamp = schemas.StrSchema
            transaction_hash = schemas.StrSchema
            
            
            class direction(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "send": "SEND",
                        "receive": "RECEIVE",
                    }
                
                @schemas.classproperty
                def SEND(cls):
                    return cls("send")
                
                @schemas.classproperty
                def RECEIVE(cls):
                    return cls("receive")
            __annotations__ = {
                "block_number": block_number,
                "block_timestamp": block_timestamp,
                "transaction_hash": transaction_hash,
                "direction": direction,
            }

    
    block_timestamp: MetaOapg.properties.block_timestamp
    block_number: MetaOapg.properties.block_number
    transaction_hash: MetaOapg.properties.transaction_hash
    direction: MetaOapg.properties.direction
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["direction"]) -> MetaOapg.properties.direction: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["block_number", "block_timestamp", "transaction_hash", "direction", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["direction"]) -> MetaOapg.properties.direction: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["block_number", "block_timestamp", "transaction_hash", "direction", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, str, ],
        block_number: typing.Union[MetaOapg.properties.block_number, str, ],
        transaction_hash: typing.Union[MetaOapg.properties.transaction_hash, str, ],
        direction: typing.Union[MetaOapg.properties.direction, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TokenTimestamp':
        return super().__new__(
            cls,
            *args,
            block_timestamp=block_timestamp,
            block_number=block_number,
            transaction_hash=transaction_hash,
            direction=direction,
            _configuration=_configuration,
            **kwargs,
        )
