# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.block_block_number_or_hash.get import GetBlock
from openapi_evm_api.paths.block_block_number_or_hash_stats.get import GetBlockStats
from openapi_evm_api.paths.date_to_block.get import GetDateToBlock


class BlockApi(
    GetBlock,
    GetBlockStats,
    GetDateToBlock,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
